# ToDo Items

NB I am not promising any timescale on any of these items...

-   Rework the name mapping to not force the current structure into the pythonic
    style naming - detailed in issue #2. This would be a breaking change.
-   Deal with the Table response handling not being reversible - so we have no
    way to convert table named tuples into correct XML. This is not necessary
    for most peoples use of the code, but pretty much everything else is
    reversible.

---
